@@ -1,5 +1,3 @@
-package Params::Callbacks;
-BEGIN { $Params::Callbacks::VERSION = '2.152500'; }
 =pod
 
 =encoding utf-8
@@ -10,7 +8,7 @@ Params::Callbacks - Make your subroutines accept blocking callbacks
 
 =head1 VERSION
 
-version 2.152500
+version 2.152510
 
 =head1 SYNOPSIS
 
@@ -49,9 +47,25 @@ version 2.152500
 =head1 DESCRIPTION
 
 Use this module to enable a function or method to accept optional blocking
-callbacks. Perhaps you would like to allow the caller to accept your function's
-return value as is, or to intercept, change, eliminate, or otherwise process that
-result before it is finally returned.
+callbacks. 
+
+Perhaps you would like to keep your implementation lightweight, while 
+providing the caller with an opportunity to modify its result before it 
+is finally returned to the calling scope.
+
+Callbacks are a fabulous for two reasons:
+
+=over
+
+=item * They reduce the need by the implementer to produce reams of speculative,
+kitchen-sink code, helping to keep functions and methods lightweight and focussed
+upon doing what is important.
+
+=item * They reduce the need by the caller to litter the calling scope with 
+lexical cruft that will never be used again. All of that can be localised within 
+a transformative callback, to be disposed of at the end of its scope.
+
+=back
 
 =head2 How callbacks are identified and processed
 
@@ -147,9 +161,11 @@ chain is terminated for that value.
 
 =cut
 
+package Params::Callbacks;
+BEGIN { $Params::Callbacks::VERSION = '2.152510'; }
+# ABSTRACT: Use to enable subroutines to accept optional blocking callbacks. 
 use strict;
 use warnings;
-
 use Exporter ();
 use Scalar::Util qw(blessed);
 use Carp qw(confess);
@@ -228,8 +244,8 @@ sub transform
 {
     my ( $callbacks, @data ) = @_;
 
-    confess
-      'E-PARAMS-CALLBACKS-001 Expected Params::Callbacks object reference as first argument'
+    confess 'E-PARAMS-CALLBACKS-001 Expected Params::Callbacks object reference '
+      . 'as first argument'
       unless ref($callbacks) && $callbacks->isa(__PACKAGE__);
 
     for my $callback (@$callbacks) {
